Documentation
¶
Overview ¶
Package types is a package that contains some generic data types.
Package types is a package that contains some generic data types.
Package types is a package that contains some generic data types.
Package types is a package that contains some generic data types.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ArrayType ¶
type ArrayType struct {
data.BaseValueType
// contains filtered or unexported fields
}
ArrayType is a generic array type that can hold any array data type. It implements the data.ValueType interface.
func (*ArrayType) GetTypeKind ¶
GetTypeKind returns the data.Kind of the ArrayType.
func (*ArrayType) GetTypeName ¶
func (*ArrayType) GetTypeSize ¶
func (*ArrayType) GetValueSize ¶
type BoolType ¶
type BoolType struct {
data.BaseValueType
// contains filtered or unexported fields
}
func (*BoolType) GetTypeKind ¶
func (*BoolType) GetTypeName ¶
func (*BoolType) GetValueSize ¶
type IntegerType ¶
type IntegerType struct {
data.BaseValueType
// contains filtered or unexported fields
}
func (*IntegerType) GetTypeKind ¶
func (t *IntegerType) GetTypeKind() data.Kind
func (*IntegerType) GetTypeName ¶
func (t *IntegerType) GetTypeName() string
func (*IntegerType) GetValue ¶
func (t *IntegerType) GetValue() any
func (*IntegerType) GetValueSize ¶
func (t *IntegerType) GetValueSize() uint64
func (*IntegerType) Parse ¶
func (t *IntegerType) Parse(v any) error
type StringType ¶
type StringType struct {
data.BaseValueType
// contains filtered or unexported fields
}
func (*StringType) GetTypeKind ¶
func (t *StringType) GetTypeKind() data.Kind
func (*StringType) GetTypeName ¶
func (t *StringType) GetTypeName() string
func (*StringType) GetValue ¶
func (t *StringType) GetValue() any
func (*StringType) GetValueSize ¶
func (t *StringType) GetValueSize() uint64
func (*StringType) Parse ¶
func (t *StringType) Parse(p any) error
Click to show internal directories.
Click to hide internal directories.